@@ -4,12 +4,13 @@ import tarfile
 import tempfile
 from pathlib import Path
 
+import dask.dataframe as dd
+import numpy as np
 import pandas as pd
-from dask import dataframe as dd
 
 from featuretools.entityset.relationship import Relationship
 from featuretools.entityset.serialize import FORMATS
-from featuretools.utils.gen_utils import check_schema_version
+from featuretools.utils.gen_utils import check_schema_version, import_or_raise
 from featuretools.utils.s3_utils import get_transport_params, use_smartopen_es
 from featuretools.utils.wrangle import _is_s3, _is_url
 from featuretools.variable_types import LatLong, find_variable_types
@@ -77,6 +78,7 @@ def description_to_entityset(description, **kwargs):
     check_schema_version(description, 'entityset')
 
     from featuretools.entityset import EntitySet
+
     # If data description was not read from disk, path is None.
     path = description.get('path')
     entityset = EntitySet(description['id'])
@@ -127,8 +129,15 @@ def read_entity_data(description, path):
     kwargs = description['loading_info'].get('params', {})
     load_format = description['loading_info']['type']
     entity_type = description['loading_info'].get('entity_type', 'pandas')
+    read_kwargs = {}
     if entity_type == 'dask':
         lib = dd
+    elif entity_type == 'koalas':
+        import_error = 'Cannot load Koalas entityset - unable to import Koalas. ' \
+                       'Consider doing a pip install with featuretools[koalas] to install Koalas with pip'
+        lib = import_or_raise('databricks.koalas', import_error)
+        read_kwargs['multiline'] = True
+        kwargs['compression'] = str(kwargs['compression'])
     else:
         lib = pd
     if load_format == 'csv':
@@ -137,6 +146,7 @@ def read_entity_data(description, path):
             engine=kwargs['engine'],
             compression=kwargs['compression'],
             encoding=kwargs['encoding'],
+            **read_kwargs
         )
     elif load_format == 'parquet':
         dataframe = lib.read_parquet(file, engine=kwargs['engine'])
@@ -146,6 +156,12 @@ def read_entity_data(description, path):
         error = 'must be one of the following formats: {}'
         raise ValueError(error.format(', '.join(FORMATS)))
     dtypes = description['loading_info']['properties']['dtypes']
+    if entity_type == 'koalas':
+        for col, dtype in dtypes.items():
+            if dtype == 'object':
+                dtypes[col] = 'string'
+            if dtype == 'datetime64[ns]':
+                dtypes[col] = np.datetime64
     dataframe = dataframe.astype(dtypes)
 
     if load_format in ['parquet', 'csv']:
@@ -154,16 +170,22 @@ def read_entity_data(description, path):
             if var_description['type']['value'] == LatLong.type_string:
                 latlongs.append(var_description["id"])
 
-        def parse_latlong(x):
+        def parse_latlong_tuple(x):
             return tuple(float(y) for y in x[1:-1].split(","))
 
+        def parse_latlong_list(x):
+            return list(float(y) for y in x[1:-1].split(","))
+
         for column in latlongs:
             if entity_type == 'dask':
                 meta = (column, tuple([float, float]))
-                dataframe[column] = dataframe[column].apply(parse_latlong,
+                dataframe[column] = dataframe[column].apply(parse_latlong_tuple,
                                                             meta=meta)
+            elif entity_type == 'koalas':
+                dataframe[column] = dataframe[column].apply(parse_latlong_list)
+
             else:
-                dataframe[column] = dataframe[column].apply(parse_latlong)
+                dataframe[column] = dataframe[column].apply(parse_latlong_tuple)
 
     return dataframe
 
