@@ -9,6 +9,7 @@ from featuretools.primitives.base.aggregation_primitive_base import (
     AggregationPrimitive
 )
 from featuretools.utils import convert_time_units
+from featuretools.utils.gen_utils import Library
 from featuretools.variable_types import (
     Boolean,
     Categorical,
@@ -33,14 +34,14 @@ class Count(AggregationPrimitive):
     return_type = Numeric
     stack_on_self = False
     default_value = 0
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type in [Library.DASK, Library.KOALAS]:
+            return 'count'
 
-    def get_function(self):
         return pd.Series.count
 
-    def get_dask_aggregation(self):
-        return 'count'
-
     def generate_name(self, base_feature_names, relationship_path_name,
                       parent_entity_id, where_str, use_prev_str):
         return u"COUNT(%s%s%s)" % (relationship_path_name,
@@ -61,14 +62,14 @@ class Sum(AggregationPrimitive):
     stack_on_self = False
     stack_on_exclude = [Count]
     default_value = 0
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type in [Library.DASK, Library.KOALAS]:
+            return 'sum'
 
-    def get_function(self):
         return np.sum
 
-    def get_dask_aggregation(self):
-        return 'sum'
-
 
 class Mean(AggregationPrimitive):
     """Computes the average for a list of values.
@@ -91,12 +92,15 @@ class Mean(AggregationPrimitive):
     name = "mean"
     input_types = [Numeric]
     return_type = Numeric
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, skipna=True):
         self.skipna = skipna
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type in [Library.DASK, Library.KOALAS]:
+            return 'mean'
+
         if self.skipna:
             # np.mean of series is functionally nanmean
             return np.mean
@@ -106,9 +110,6 @@ class Mean(AggregationPrimitive):
 
         return mean
 
-    def get_dask_aggregation(self):
-        return 'mean'
-
 
 class Mode(AggregationPrimitive):
     """Determines the most commonly repeated value.
@@ -127,7 +128,7 @@ class Mode(AggregationPrimitive):
     input_types = [Discrete]
     return_type = None
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         def pd_mode(s):
             return s.mode().get(0, np.nan)
 
@@ -146,14 +147,14 @@ class Min(AggregationPrimitive):
     input_types = [Numeric]
     return_type = Numeric
     stack_on_self = False
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type in [Library.DASK, Library.KOALAS]:
+            return 'min'
 
-    def get_function(self):
         return np.min
 
-    def get_dask_aggregation(self):
-        return 'min'
-
 
 class Max(AggregationPrimitive):
     """Calculates the highest value, ignoring `NaN` values.
@@ -167,14 +168,14 @@ class Max(AggregationPrimitive):
     input_types = [Numeric]
     return_type = Numeric
     stack_on_self = False
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type in [Library.DASK, Library.KOALAS]:
+            return 'max'
 
-    def get_function(self):
         return np.max
 
-    def get_dask_aggregation(self):
-        return 'max'
-
 
 class NumUnique(AggregationPrimitive):
     """Determines the number of distinct values, ignoring `NaN` values.
@@ -193,31 +194,32 @@ class NumUnique(AggregationPrimitive):
     input_types = [Discrete]
     return_type = Numeric
     stack_on_self = False
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type == Library.DASK:
+            def chunk(s):
+                def inner_chunk(x):
+                    x = x[:].dropna()
+                    return set(x.unique())
+                return s.agg(inner_chunk)
+
+            def agg(s):
+                def inner_agg(x):
+                    x = x[:].dropna()
+                    return(set().union(*x.values))
+                return s.agg(inner_agg)
+
+            def finalize(s):
+                return s.apply(lambda x: len(x))
+
+            return dd.Aggregation(self.name, chunk=chunk, agg=agg, finalize=finalize)
+
+        elif agg_type == Library.KOALAS:
+            return 'nunique'
 
-    def get_function(self):
         return pd.Series.nunique
 
-    def get_dask_aggregation(self):
-        def chunk(s):
-            def inner_chunk(x):
-                x = x[:].dropna()
-                return set(x.unique())
-
-            return s.agg(inner_chunk)
-
-        def agg(s):
-            def inner_agg(x):
-                x = x[:].dropna()
-                return(set().union(*x.values))
-
-            return s.agg(inner_agg)
-
-        def finalize(s):
-            return s.apply(lambda x: len(x))
-
-        return dd.Aggregation(self.name, chunk=chunk, agg=agg, finalize=finalize)
-
 
 class NumTrue(AggregationPrimitive):
     """Counts the number of `True` values.
@@ -237,23 +239,23 @@ class NumTrue(AggregationPrimitive):
     default_value = 0
     stack_on = []
     stack_on_exclude = []
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type == Library.DASK:
+            def chunk(s):
+                chunk_sum = s.agg(np.sum)
+                if chunk_sum.dtype == 'bool':
+                    chunk_sum = chunk_sum.astype('int64')
+                return chunk_sum
+
+            def agg(s):
+                return s.agg(np.sum)
+
+            return dd.Aggregation(self.name, chunk=chunk, agg=agg)
 
-    def get_function(self):
         return np.sum
 
-    def get_dask_aggregation(self):
-        def chunk(s):
-            chunk_sum = s.agg(np.sum)
-            if chunk_sum.dtype == 'bool':
-                chunk_sum = chunk_sum.astype('int64')
-            return chunk_sum
-
-        def agg(s):
-            return s.agg(np.sum)
-
-        return dd.Aggregation(self.name, chunk=chunk, agg=agg)
-
 
 class PercentTrue(AggregationPrimitive):
     """Determines the percent of `True` values.
@@ -275,35 +277,35 @@ class PercentTrue(AggregationPrimitive):
     stack_on = []
     stack_on_exclude = []
     default_value = 0
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type == Library.DASK:
+            def chunk(s):
+                def format_chunk(x):
+                    return x[:].fillna(0)
+
+                chunk_sum = s.agg(lambda x: format_chunk(x).sum())
+                chunk_len = s.agg(lambda x: len(format_chunk(x)))
+                if chunk_sum.dtype == 'bool':
+                    chunk_sum = chunk_sum.astype('int64')
+                if chunk_len.dtype == 'bool':
+                    chunk_len = chunk_len.astype('int64')
+                return (chunk_sum, chunk_len)
+
+            def agg(val, length):
+                return (val.sum(), length.sum())
+
+            def finalize(total, length):
+                return total / length
+
+            return dd.Aggregation(self.name, chunk=chunk, agg=agg, finalize=finalize)
 
-    def get_function(self):
         def percent_true(s):
             return s.fillna(0).mean()
 
         return percent_true
 
-    def get_dask_aggregation(self):
-        def chunk(s):
-            def format_chunk(x):
-                return x[:].fillna(0)
-
-            chunk_sum = s.agg(lambda x: format_chunk(x).sum())
-            chunk_len = s.agg(lambda x: len(format_chunk(x)))
-            if chunk_sum.dtype == 'bool':
-                chunk_sum = chunk_sum.astype('int64')
-            if chunk_len.dtype == 'bool':
-                chunk_len = chunk_len.astype('int64')
-            return (chunk_sum, chunk_len)
-
-        def agg(val, length):
-            return (val.sum(), length.sum())
-
-        def finalize(total, length):
-            return total / length
-
-        return dd.Aggregation(self.name, chunk=chunk, agg=agg, finalize=finalize)
-
 
 class NMostCommon(AggregationPrimitive):
     """Determines the `n` most common elements.
@@ -332,7 +334,7 @@ class NMostCommon(AggregationPrimitive):
         self.n = n
         self.number_output_features = n
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         def n_most_common(x):
             array = np.array(x.value_counts().index[:self.n])
             if len(array) < self.n:
@@ -375,7 +377,7 @@ class AvgTimeBetween(AggregationPrimitive):
     def __init__(self, unit="seconds"):
         self.unit = unit.lower()
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         def pd_avg_time_between(x):
             """Assumes time scales are closer to order
             of seconds than to nanoseconds
@@ -423,7 +425,7 @@ class Median(AggregationPrimitive):
     input_types = [Numeric]
     return_type = Numeric
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         return pd.Series.median
 
 
@@ -446,7 +448,7 @@ class Skew(AggregationPrimitive):
     stack_on = []
     stack_on_self = False
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         return pd.Series.skew
 
 
@@ -462,14 +464,14 @@ class Std(AggregationPrimitive):
     input_types = [Numeric]
     return_type = Numeric
     stack_on_self = False
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type in [Library.DASK, Library.KOALAS]:
+            return 'std'
 
-    def get_function(self):
         return np.std
 
-    def get_dask_aggregation(self):
-        return 'std'
-
 
 class First(AggregationPrimitive):
     """Determines the first value in a list.
@@ -484,7 +486,7 @@ class First(AggregationPrimitive):
     return_type = None
     stack_on_self = False
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         def pd_first(x):
             return x.iloc[0]
 
@@ -504,7 +506,7 @@ class Last(AggregationPrimitive):
     return_type = None
     stack_on_self = False
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         def pd_last(x):
             return x.iloc[-1]
 
@@ -527,20 +529,20 @@ class Any(AggregationPrimitive):
     input_types = [Boolean]
     return_type = Boolean
     stack_on_self = False
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type == Library.DASK:
+            def chunk(s):
+                return s.agg(np.any)
+
+            def agg(s):
+                return s.agg(np.any)
+
+            return dd.Aggregation(self.name, chunk=chunk, agg=agg)
 
-    def get_function(self):
         return np.any
 
-    def get_dask_aggregation(self):
-        def chunk(s):
-            return s.agg(np.any)
-
-        def agg(s):
-            return s.agg(np.any)
-
-        return dd.Aggregation(self.name, chunk=chunk, agg=agg)
-
 
 class All(AggregationPrimitive):
     """Calculates if all values are 'True' in a list.
@@ -558,20 +560,20 @@ class All(AggregationPrimitive):
     input_types = [Boolean]
     return_type = Boolean
     stack_on_self = False
-    dask_compatible = True
+    compatibility = [Library.PANDAS, Library.DASK]
+
+    def get_function(self, agg_type=Library.PANDAS):
+        if agg_type == Library.DASK:
+            def chunk(s):
+                return s.agg(np.all)
+
+            def agg(s):
+                return s.agg(np.all)
+
+            return dd.Aggregation(self.name, chunk=chunk, agg=agg)
 
-    def get_function(self):
         return np.all
 
-    def get_dask_aggregation(self):
-        def chunk(s):
-            return s.agg(np.all)
-
-        def agg(s):
-            return s.agg(np.all)
-
-        return dd.Aggregation(self.name, chunk=chunk, agg=agg)
-
 
 class TimeSinceLast(AggregationPrimitive):
     """Calculates the time elapsed since the last datetime (default in seconds).
@@ -614,7 +616,7 @@ class TimeSinceLast(AggregationPrimitive):
     def __init__(self, unit="seconds"):
         self.unit = unit.lower()
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         def time_since_last(values, time=None):
             time_since = time - values.iloc[-1]
             return convert_time_units(time_since.total_seconds(), self.unit)
@@ -663,7 +665,7 @@ class TimeSinceFirst(AggregationPrimitive):
     def __init__(self, unit="seconds"):
         self.unit = unit.lower()
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         def time_since_first(values, time=None):
             time_since = time - values.iloc[0]
             return convert_time_units(time_since.total_seconds(), self.unit)
@@ -694,7 +696,7 @@ class Trend(AggregationPrimitive):
     input_types = [Numeric, DatetimeTimeIndex]
     return_type = Numeric
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         def pd_trend(y, x):
             df = pd.DataFrame({"x": x, "y": y}).dropna()
             if df.shape[0] <= 2:
@@ -781,7 +783,7 @@ class Entropy(AggregationPrimitive):
         self.dropna = dropna
         self.base = base
 
-    def get_function(self):
+    def get_function(self, agg_type=Library.PANDAS):
         def pd_entropy(s):
             distribution = s.value_counts(normalize=True, dropna=self.dropna)
             return stats.entropy(distribution, base=self.base)
